Crate serialport_stream

Crate serialport_stream 

serialport-stream

Pure event driven implementation of futures::Stream for reading data from serialport utilizing serialport-rs. Produces 1-N amount of bytes depending on polling interval. Initial poll starts background thread which will indefinitely wait for data in event, error or drop.

Re-exports

pub use serialport;

Structs

SerialPortStream
An async stream for reading from a serial port.
SerialPortStreamBuilder
Builder for configuring and opening a serial port stream.

Traits

Stream
A stream of values produced asynchronously.
TryStreamExt
Adapters specific to Result-returning streams

Functions

new
Creates a new serial port stream builder.